package com.chinaitop.agile.controller;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.DataKcglFcbgzDefault;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample;
import com.chinaitop.agile.model.DataKcglKcswDefault;
import com.chinaitop.agile.model.DataKcglKcswDefaultExample;
import com.chinaitop.agile.model.DataKcglKcswDefaultExample.Criteria;
import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.service.KcswService;
import com.chinaitop.agile.utils.ParameterUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/kcsw")
@Api(value= "KcswController", description = "库存实物控制类")
public class KcswController {

	@Resource
	private KcswService kcswService;
	
	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;

    @RequestMapping(value="/getDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="首页柱形图", notes = "首页柱形图")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
    public Map<String, Object> getDate(Integer orgId) {
        Map<String, Object> queryByExample = kcswService.queryByExample(orgId);
        return queryByExample;
    }

    @RequestMapping(value="/countByBl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询库存总量", notes = "根据库存总量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
    public Map<String, Object> countByBl(Integer orgId) {
    	Map<String, Object> map = kcswService.countByBlType(orgId);
		return map;
	}

    @RequestMapping(value="/getDateDj", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据1~3等粮食的总数量(首页饼图)", notes = "根据1~3等粮食的总数量(首页饼图)")
	@ApiImplicitParams({
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query")
	})
    public Map<String, Object> getDateDj(Integer orgId) {
        Map<String, Object> queryByExample = kcswService.queryByDj(orgId);
        return queryByExample;
    }

    @RequestMapping(value="/getDateBl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询库存库容比(首页仪表盘)", notes = "查询库存库容比(首页仪表盘)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "effectiveCapacity", value = "有效仓容", paramType = "query"),
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query")
	})
    public String getDateBl(String effectiveCapacity, Integer orgId) {
    	Map<String, Object> map = new HashMap<String, Object>();
    	map.put("orgId", orgId);
        String queryByBl = kcswService.queryByBl(effectiveCapacity, map);
        if(StringUtils.isNotBlank(queryByBl)){
        	return queryByBl;
        }
        return null;
    }

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="库存数量管理列表数据查询", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query"),
        @ApiImplicitParam(name = "order", value = "排序方式", paramType = "query")
	})
    public PageInfo<DataKcglKcswDefault> getList(Integer pageNum, Integer pageSize, String kcswStr,
    		String order){
    	PageInfo<DataKcglKcswDefault> pageInfo = null;
		try {
			pageInfo = kcswService.queryYYSSL(pageNum, pageSize, kcswStr, order);
		} catch (Exception e) {
			e.printStackTrace();
		}
    	return pageInfo;
    }
	
	@RequestMapping(value="/importList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="导出库存数量数据为Excel", notes = "")
	@ApiImplicitParams({
        @ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query"),
        @ApiImplicitParam(name = "order", value = "排序方式", paramType = "query")
	})
    public List<DataKcglKcswDefault> importList(HttpServletRequest request, HttpServletResponse response, String kcswStr, String order){
    	List<DataKcglKcswDefault> list = null;
		try {
			list = kcswService.importList(request, response, kcswStr, order);
		} catch (Exception e) {
			e.printStackTrace();
		}
    	return list;
    }

    @RequestMapping(value="/getHouseOrWareList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "list", value = "符合轮换计划的第三方检查的数据", paramType = "query")
	})
    public List<Integer> getHouseIdList(String list,Integer orgId) {
        List<Integer> list1 = new ArrayList<Integer>();
        Map<String, Object> modelMap = new HashMap<>();
        modelMap.put("UnitID", orgId);
        if(list!=null){
        	list = "["+list+"]";
            List<Map<String,Object>> listQuality = new Gson().fromJson(list, new TypeToken<List<Map<String,Object>>>(){}.getType());  
            for (int i = 0; i < listQuality.size(); i++) {
                Map<String,Object> map = (Map<String,Object>)listQuality.get(i);
                //int houseId=listQuality.get(i).getHouseId();
                String id = ObjectUtils.toString(map.get("house_id"));
                if(id.indexOf(".") != -1) {
                    id = id.substring(0,id.indexOf("."));
                }
                int houseId=Integer.parseInt(id);
                if(!list1.contains(houseId)){
                    list1.add(houseId);
                }
            }
        }
        
        List<DataKcglKcswDefault> listKc = kcswService.getHouseOrWareList(modelMap);
        for (int j = 0; j < listKc.size(); j++) {
              int houseId=listKc.get(j).getCh();
              list1.add(houseId);
        }
        
        return list1;
    }

    /**
     * 获取数量
     * @param groupByClause 类型
     * @return
     */
    @RequestMapping(value="/getCount", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取数量", notes = "获取数量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "groupByClause", value = "类型", paramType = "query")
	})
    public Map<String, Object> getCount(String groupByClause) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        List<Map<String, Object>> resultList = new ArrayList<>();
        if (groupByClause.compareTo("pz")==0) {
            resultList = kcswService.selectCountByPz();
        }
        if (groupByClause.compareTo("xz")==0) {
            resultList = kcswService.selectCountByXz();
        }
        if (groupByClause.compareTo("year")==0) {
            resultList = kcswService.selectCountByYear();
        }
        if (groupByClause.compareTo("city")==0) {
            resultList = kcswService.selectCountByCity();
        }
        modelMap.put("result", resultList);
        return modelMap;
    }
    
    /**
     * 获取库存数量
     * @param storehouseId 仓房id
     * @param warehouseId 货位id
     * @return
     * @throws Exception 
     */
    @RequestMapping(value="/getMassageBych", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取库存数量", notes = "获取库存数量")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "storehouseId", value = "仓房id", paramType = "query"),
		@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
		@ApiImplicitParam(name = "qualitycheckList", value = "货位id", paramType = "query"),
	})
    public Map<String, Object> getMassageBych(Integer storehouseId,Integer warehouseId,String qualitycheckList) throws Exception {
    	Map<String, Object> map = new HashMap<String, Object>();
    	if(storehouseId!=null && warehouseId!=null){
    		Map<String, Object> modelMap = new HashMap<String, Object>();
        	modelMap.put("storehouseId", storehouseId);
        	modelMap.put("warehouseId", warehouseId);
        	List<DataKcglKcswDefault> list = kcswService.getMassageBych(modelMap);
        	//给生产年份赋值
    		if (null != list && list.size() > 0) {
    			for (DataKcglKcswDefault dataKcglKcswDefault : list) {
    				DataKcglFcbgzDefaultExample fcbgz_example = new DataKcglFcbgzDefaultExample();
    				DataKcglFcbgzDefaultExample.Criteria fcbgz_criteria = fcbgz_example.createCriteria();
    				fcbgz_criteria.andUnitidEqualTo(dataKcglKcswDefault.getUnitid());
    				fcbgz_criteria.andChEqualTo(dataKcglKcswDefault.getCh());
    				fcbgz_criteria.andHwhEqualTo(dataKcglKcswDefault.getHwh());
    				fcbgz_criteria.andSrslGreaterThan(0d);//收入数量大于0
    				fcbgz_example.setOrderByClause(" rq DESC");
    				List<DataKcglFcbgzDefault> fcbgz_list = fcbgzService.findByList(fcbgz_example);
    				if (null != fcbgz_list && fcbgz_list.size() > 0) {
    					int scnf = Integer.parseInt(ObjectUtils.toString(fcbgz_list.get(0).getScnf(), "0"));
    					dataKcglKcswDefault.setScnf(scnf);
    				}
    			}
    		}
        	map.put("list", list);
    	}

    	if(qualitycheckList!=null){
    		map.put("qualitycheckList", qualitycheckList);
    	}
    	
    	
    	return map;
    }

	/**
	 * 查询出入库最新粮库储粮信息--首页用到
	 */
	@RequestMapping(value="/queryLKNewData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询出入库信息", notes = "查询出入库最新粮库储粮信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public List<DataKcglKcswDefault> queryLKNewData(Integer orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (null != orgId) {
			map.put("orgId", orgId + "");
		}
		return kcswService.queryLKNewData(map);
	}
	
	
	/**
	 * 获取计划中预警数据
	 */
	@RequestMapping(value="/getWarningList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "days", value = "提前几天提醒", paramType = "query"),
		@ApiImplicitParam(name = "list", value = "集合", paramType = "query")
	})
	public PageInfo<DataKcglKcswDefault> getHouseIdList(Integer pageNum, Integer pageSize,Integer days,String list,DataKcglKcswDefault kcsw,Integer orgId) {
		
        if (days == null) {
        	days=0;
        }
        
        List<DataKcglKcswDefault> olist = new ArrayList<DataKcglKcswDefault>();
       if(null != list){
    	   list = "["+list+"]";
           List<Map<String,Object>> listQuality = new Gson().fromJson(list, new TypeToken<List<Map<String,Object>>>(){}.getType());  
           DataKcglKcswDefault dataKcglKcswDefault=new DataKcglKcswDefault();
           
           for (int i = 0; i < listQuality.size(); i++) {
               Map<String,Object> map = (Map<String,Object>)listQuality.get(i);
               
               String houseId = ObjectUtils.toString(map.get("house_id"));
               String warehouseId = ObjectUtils.toString(map.get("warehouse_id"));
               String subType=String.valueOf(map.get("sub_type_detailed"));
               String quality = ObjectUtils.toString(map.get("quality"));
               String level1=String.valueOf(map.get("level"));
               String level = ObjectUtils.toString(level1);
               String number = ObjectUtils.toString(map.get("number"));
               
               if(houseId.indexOf(".") != -1) {
               	houseId = houseId.substring(0,houseId.indexOf("."));
               }
               if(warehouseId.indexOf(".") != -1) {
               	warehouseId = houseId.substring(0,warehouseId.indexOf("."));
               }
               if(subType.indexOf(".") != -1) {
               	subType = subType.substring(0,subType.indexOf("."));
               }
               if(level.indexOf(".") != -1) {
               	level = level.substring(0,level.indexOf("."));
               }
               dataKcglKcswDefault.setCh(Integer.parseInt(houseId));
               dataKcglKcswDefault.setHwh(Integer.parseInt(warehouseId));
               dataKcglKcswDefault.setHwxz(quality);
             
               dataKcglKcswDefault.setPz(String.valueOf(subType));
               dataKcglKcswDefault.setDj(level);
               dataKcglKcswDefault.setKcsl(Double.parseDouble(number));
               olist.add(dataKcglKcswDefault);
           }
		}
		 
       
        

		DataKcglKcswDefaultExample example = new DataKcglKcswDefaultExample();
		Criteria criteria = example.createCriteria();
		criteria.andUnitidEqualTo(orgId.toString());
			
		//获取当前时间，转化格式
		Date date = new Date();  
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss");  
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.DAY_OF_YEAR, days);//正数可以得到当前时间+n天，负数可以得到当前时间-n天
        
        date = calendar.getTime();
        calendar.setTime(date);
		

        if(ParameterUtil.isnotnull(date)){
        	calendar.add(Calendar.YEAR, -2); // 年份减2
        	date = calendar.getTime();
            calendar.setTime(date);
            String time = sdf.format(date);
        	Date endDate = ParameterUtil.string2datetime(time);
        	criteria.andPzEqualTo("3164");
        	criteria.andRqLessThanOrEqualTo(endDate);
        }
        
        List<DataKcglKcswDefault> list2 = kcswService.findCondition(example);
        
        DataKcglKcswDefaultExample example1 = new DataKcglKcswDefaultExample();
		Criteria criteria1= example1.createCriteria();
		criteria1.andUnitidEqualTo(orgId.toString());
		
        //其他的轮换时间三年
        if(ParameterUtil.isnotnull(date)){
        	calendar.add(Calendar.YEAR, -1); // 年份减3(calendar获取上面的时间已经减去2年,此时减少一年 即可)
        	date = calendar.getTime();
            calendar.setTime(date);
            String time = sdf.format(date);
        	Date endDate = ParameterUtil.string2datetime(time);
        	criteria1.andPzNotEqualTo("3164");
        	criteria1.andRqLessThanOrEqualTo(endDate);
        	
        }
        List<DataKcglKcswDefault> list3 = kcswService.findCondition(example1);
        
        
        if(list3!=null && list3.size()>0){
        	for (DataKcglKcswDefault dataKcglKcswDefault3 : list3) {
        		olist.add(dataKcglKcswDefault3);
        	}
        }
        if(list2!=null && list2.size()>0){
        	for (DataKcglKcswDefault dataKcglKcswDefault2 : list2) {
        		olist.add(dataKcglKcswDefault2);
        	}
        }
        if(pageNum!=null && pageSize!=null){
            PageHelper.startPage(pageNum, pageSize);
        }
        PageInfo<DataKcglKcswDefault> pageInfo = new PageInfo<DataKcglKcswDefault>(olist);
        if(pageInfo.getTotal()>0){
        	pageInfo.setStartRow(pageInfo.getStartRow()+1);
        	pageInfo.setEndRow(pageInfo.getEndRow()+1);
        }
        return pageInfo;
    
	}

	@RequestMapping(value="/emptyKcsw", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="获取仓房或者货位", notes = "仓房或者货位")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "userInfo", value = "登录对象", paramType = "form"),
		@ApiImplicitParam(name = "profitlossSheet", value = "损益单对象", paramType = "form")
	})
	public Map<String, Object> emptyKcsw(String userInfo, String profitlossSheet) {

		Map<String, Object> map = new HashMap<String, Object>();

		/* 更新分仓保管账表、形成库存表、库存实物表  */
		kcswService.updateKc(userInfo, profitlossSheet);

		return map;
	}
	
	
	/**
	 * 销售计划 查询当前组织的库存信息
	 * @throws Exception 
	 */
	@RequestMapping(value="/queryKcData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前组织的库存信息", notes = "查询当前组织的库存信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "登录对象", paramType = "form")
	})
	public List<DataKcglKcswDefault> queryKcData(Integer orgId,Integer houseId,Integer warehouseId) throws Exception{
		List<DataKcglKcswDefault> kcList = kcswService.queryKcData(orgId,houseId,warehouseId);
		//给生产年份赋值
		if (null != kcList && kcList.size() > 0) {
			for (DataKcglKcswDefault dataKcglKcswDefault : kcList) {
				DataKcglFcbgzDefaultExample fcbgz_example = new DataKcglFcbgzDefaultExample();
				DataKcglFcbgzDefaultExample.Criteria fcbgz_criteria = fcbgz_example.createCriteria();
				fcbgz_criteria.andUnitidEqualTo(dataKcglKcswDefault.getUnitid());
				fcbgz_criteria.andChEqualTo(dataKcglKcswDefault.getCh());
				fcbgz_criteria.andHwhEqualTo(dataKcglKcswDefault.getHwh());
				fcbgz_criteria.andSrslGreaterThan(0d);//收入数量大于0
				fcbgz_example.setOrderByClause(" rq DESC");
				List<DataKcglFcbgzDefault> fcbgz_list = fcbgzService.findByList(fcbgz_example);
				if (null != fcbgz_list && fcbgz_list.size() > 0) {
					int scnf = Integer.parseInt(ObjectUtils.toString(fcbgz_list.get(0).getScnf(), "0"));
					dataKcglKcswDefault.setScnf(scnf);
				}
			}
		}
		
		return kcList;
	}

	@RequestMapping(value="/queryKcswData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="库存实物记录查询", notes = "库存实物记录查询")
	@ApiImplicitParams({
		@ApiImplicitParam(name="datas", value="条件", paramType="query")
	})
	public List<Map<String, Object>> queryKcswData(String datas) {

		ObjectMapper mapper = new ObjectMapper();
		List<Map<String, Object>> result_list = new ArrayList<Map<String, Object>>();

		DataKcglKcswDefault kcsw = null;
		Map<String, Object> param_map = null;
		List<Map<String, Object>> list = null;
		try {
			List<DataKcglKcswDefault> param_List = mapper.readValue(datas, new TypeReference<List<DataKcglKcswDefault>>(){});
			if (null != param_List && param_List.size() > 0) {
				for (DataKcglKcswDefault obj : param_List) {
					kcsw = obj;
					param_map = new HashMap<String, Object>();

					/* 单位 */
					if (null != kcsw.getUnitid()) {
						param_map.put("orgId", kcsw.getUnitid());
					}

					/* 货位 */
					if (null != kcsw.getHwh()) {
						param_map.put("wareId", kcsw.getHwh());
					}

					list = kcswService.findAgentCondition(param_map);
					//给生产年份赋值
					if (null != list && list.size() > 0) {
						Map<String, Object> obj1 = null;
						for (int i = list.size()-1; i >= 0; i--) {
							//obj1.setOlddataid(ParameterUtil.date2string(obj1.get("")));
							obj1 = list.get(i);
							result_list.add(obj1);
						}
					}
				}
			}
			

		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_list;
	}

	/**
	 * 根据orgId、仓房、货位 获取其他相关信息,用于市库对接
	 */
	@RequestMapping(value="/getDateByChHwh", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据orgId、仓房、货位 获取其他相关信息", notes = "根据orgId、仓房、货位 获取其他相关信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name="orgId", value="单位ID", paramType="query"),
		@ApiImplicitParam(name="houseId", value="单位ID", paramType="query"),
		@ApiImplicitParam(name="wareHouseId", value="单位ID", paramType="query")
	})
    public Map<String, Object> getDateByChHwh(String orgId,String houseId,String wareHouseId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
    	modelMap.put("orgId", orgId);
    	modelMap.put("houseId", houseId);
    	modelMap.put("wareHouseId", wareHouseId);
    	List<DataKcglKcswDefault> list = kcswService.getDateByChHwh(modelMap);
    	Integer pz = 0;
    	Integer mxpz = 0;
    	Integer dj = 0;
    	Integer hwxz = 0;
    	Integer gb = 0;
    	Date rq = new Date();
    	if(list.size()>0 && list!=null){
    		 pz = Integer.parseInt(list.get(0).getPz());
    		 mxpz = Integer.parseInt(list.get(0).getMxpz());
    		 dj = Integer.parseInt(list.get(0).getDj());
    		 hwxz = Integer.parseInt(list.get(0).getHwxz());
    		 gb = Integer.parseInt(list.get(0).getGb());
    		 rq = list.get(0).getRq();
    	}
    	modelMap.put("pz", pz);
    	modelMap.put("mxpz", mxpz);
    	modelMap.put("dj", dj);
    	modelMap.put("hwxz", hwxz);
    	modelMap.put("gb", gb);
    	modelMap.put("rq", rq);
        return modelMap;
    }
	
	/**
	 * 轮换计划 查询当前库符合条件的轮换计划
	 */
	@RequestMapping(value="/queryLhData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前库符合条件的轮换计划", notes = "查询当前库符合条件的轮换计划")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "登录对象的orgId", paramType = "form")
	})
	public List<DataKcglKcswDefault> queryLhData(Integer orgId){
		Map<String, Object> modelMap = new HashMap<>();
        modelMap.put("UnitID", orgId);
		return kcswService.getHouseOrWareList(modelMap);
	}

	/**
	 * 查询库存实物表数据和入仓时间
	 * @param kcswStr 条件集合
	 * @return
	 */
	@RequestMapping(value="/getListOrRcsj", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询库存实物表数据", notes = "支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "kcswStr", value = "条件集合", paramType = "query")
	})
	public List<DataKcglKcswDefault> getListOrRcsj(String kcswStr){
		ObjectMapper mapper = new ObjectMapper();
		DataKcglKcswDefault kcsw = null;
		List<DataKcglKcswDefault> list = null;
		try {
			if (null != kcswStr && !"".equals(kcswStr)) {
				kcsw = mapper.readValue(kcswStr, DataKcglKcswDefault.class);
			} else {
				kcsw = new DataKcglKcswDefault();
			}

			Map<String, Object> modelMap = new HashMap<String, Object>();

			/* 仓房 */
			if (null != kcsw.getCh() && !"".equals(kcsw.getCh())) {
				modelMap.put("ch", kcsw.getCh().toString());
			}
			/* 货位 */
			if (null != kcsw.getHwh() && !"".equals(kcsw.getHwh())) {
				modelMap.put("hwh", kcsw.getHwh().toString());
			}
			/* 单位 */
			if (null != kcsw.getUnitid() && !"".equals(kcsw.getUnitid())) {
				modelMap.put("unitid", kcsw.getUnitid());
			}

			list = kcswService.findListOrRcsj(modelMap);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}

	@RequestMapping(value="/queryFkcfData",produces=MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询当前库下非空仓房列表和仓房中的库存数据", notes = "")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "orgId", value = "登录对象的orgId", paramType = "query"),
			@ApiImplicitParam(name = "ch", value = "仓房ID", paramType = "query")
	})
	public Map<String, Object> queryFkcfData(String orgId, Integer ch) {
		Map<String, Object> modelMap = new HashMap<>();
		if (StringUtils.isBlank(orgId)) {
			modelMap.put("status", "error");
			modelMap.put("msg", "参数异常，单位不能为空");
			return modelMap;
		}
		try {
			modelMap = kcswService.queryFkcfData(orgId, ch);
		} catch (Exception e) {
			modelMap.put("status", "error");
			modelMap.put("msg", "请求异常");
			e.printStackTrace();
		}
		return modelMap;
	}

}
