package com.chinaitop.agile.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import com.chinaitop.agile.model.Bgmxz;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.feignService.KeepaccountFeignService;
import com.chinaitop.agile.model.DataKcglFcbgzDefault;
import com.chinaitop.agile.model.DataKcglFcbgzDefaultExample;
import com.chinaitop.agile.service.DataKcglFcbgzDefaultService;
import com.chinaitop.agile.service.KeepAccountService;
import com.chinaitop.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/keepAccount")
@Api(value= "KeepAccountController", description = "保管账控制类")
@SuppressWarnings("all")
public class KeepAccountController {
	
	@Resource
	private KeepAccountService keepAccountService;
	@Resource
	private DataKcglFcbgzDefaultService fcbgzService;
	@Resource
	private KeepaccountFeignService keepaccountFeignService;

	private final static Log logger = LogFactory.getLog(KeepAccountController.class);

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="保管明细账列表(新方法，当前保管明细账列表再用)", notes = "支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
			@ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
			@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
			@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
			@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
			@ApiImplicitParam(name="endDate", value="结束时间", paramType="query"),
			@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
	})
	public PageInfo<Bgmxz> getList(Integer pageNum, Integer pageSize,
								   Integer ch, Integer hwh, Integer lspz, Integer lsxz,
								   String startDate, String endDate, String orgId) {

		Map<String, Object> map = new HashMap<String, Object>();
		if (ch != null) {
			map.put("ch", ch);
		}
		if (hwh != null) {
			map.put("hwh", hwh);
		}
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			map.put("startDate", startDate+" 00:00:00");
		}
		if (endDate != null && !"".equals(endDate)) {
			map.put("endDate", endDate+" 23:59:59");
		}

		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<Bgmxz> list = null;
		try {
			list = keepAccountService.selectBgmxz(map);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		PageInfo<Bgmxz> pageInfo = new PageInfo<Bgmxz>(list);
		return pageInfo;
	}

	@RequestMapping(value="/list", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="保管明细账列表(旧方法，可能别的功能还在用)", notes = "保管明细账列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query"),
		@ApiImplicitParam(name="wjh", value="计划文件号", paramType="query"),
		@ApiImplicitParam(name="zy", value="摘要", paramType="query"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
	})
	public PageInfo<DataKcglFcbgzDefault> list(Integer pageNum, Integer pageSize,
			Integer ch, Integer hwh, Integer lspz, Integer lsxz, String startDate, String endDate, String wjh, String zy, String orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (ch != null) {
			map.put("ch", ch);
		}
		if (hwh != null) {
			map.put("hwh", hwh);
		}
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (startDate != null && !"".equals(startDate)) {
			map.put("startDate", startDate+" 00:00:00");
		}
		if (endDate != null && !"".equals(endDate)) {
			map.put("endDate", endDate+" 23:59:59");
		}
		//String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		if (null != orgId && !"".equals(orgId)) {
			map.put("orgId", orgId);
		}
		if (null != wjh && !"".equals(wjh)) {
			map.put("wjh", wjh);
		}
		if (null != zy && !"".equals(zy)) {
			map.put("zy", zy);
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<DataKcglFcbgzDefault> list = null;
		try {
			list = keepAccountService.selectHouseKeepAccountData(map);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}

		PageInfo<DataKcglFcbgzDefault> pageInfo = new PageInfo<DataKcglFcbgzDefault>(list);
		return pageInfo;
	}

	@RequestMapping(value="/houseKeepAccountList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="分仓保管列表，按天统计", notes = "分仓保管列表，按天统计，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ch", value = "仓号ID", paramType = "query"),
        @ApiImplicitParam(name="hwh", value="货位号ID", paramType="query"),
		@ApiImplicitParam(name="lspz", value="品种", paramType="query"),
		@ApiImplicitParam(name="lsxz", value="货物性质", paramType="query"),
		@ApiImplicitParam(name="startDate", value="开始时间", paramType="query"),
		@ApiImplicitParam(name="endDate", value="结束时间", paramType="query"),
		@ApiImplicitParam(name="wjh", value="品种", paramType="query"),
		@ApiImplicitParam(name="zy", value="摘要", paramType="query")
	})
	public PageInfo<DataKcglFcbgzDefault> houseKeepAccountList(Integer pageNum, Integer pageSize,
			Integer ch, Integer hwh, Integer lspz, Integer lsxz,
			String startDate, String endDate,
			String wjh, String zy, String orgId) {

		List<DataKcglFcbgzDefault> list = null;
		try {
			list = keepAccountService.houseKeepAccountList(pageNum, pageSize, ch, hwh, lspz, lsxz,
					startDate, endDate, wjh, zy, orgId);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		PageInfo<DataKcglFcbgzDefault> pageInfo = new PageInfo<DataKcglFcbgzDefault>(list);
		return pageInfo;
	}

}
