package com.chinaitop.agile.service;

import com.chinaitop.agile.model.DataKcglKcswDefault;
import com.chinaitop.agile.model.DataKcglKcswDefaultExample;
import com.github.pagehelper.PageInfo;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public interface KcswService {
	/**
	 * 粮食品种柱状图
	 * 
	 * @param orgId 单位ID
	 * @return
	 */
	Map<String, Object> queryByExample(Integer orgId);

	/**
	 * 根据等级饼图
	 * 
	 * @param example
	 * @return
	 */
	Map<String, Object> queryByDj(Integer orgId);

	/**
	 * 库存/库容比仪表盘图
	 * 
	 * @param effectiveCapacity 有效库容
	 * @param map 条件对象
	 * @return
	 */
	String queryByBl(String effectiveCapacity, Map<String, Object> map);

	/**
	 * 条件查询库存实物表中的数据
	 * 
	 * @param example
	 * @return
	 */
	List<DataKcglKcswDefault> findCondition(DataKcglKcswDefaultExample example);
	List<Map<String, Object>> findAgentCondition(Map<String, Object> map);

	List<DataKcglKcswDefault> getHouseOrWareList(Map<String, Object> modelMap);

	List<Map<String, Object>> selectCountByPz();

	List<Map<String, Object>> selectCountByXz();

	List<Map<String, Object>> selectCountByYear();

	List<Map<String, Object>> selectCountByCity();
	List<DataKcglKcswDefault> getMassageBych(Map<String, Object> modelMap);

	/**
	 * 查询敏捷平台最新储粮信息
	 * @return
	 */
	List<DataKcglKcswDefault> queryLKNewData(Map<String, Object> map);

	/**
	 * 损益单保存后更新库存
	 * 
	 * @param userInfo 登录对象
	 * @param profitlossSheet 损益单对象
	 */
	void updateKc(String userInfo, String profitlossSheet);

	/**
	 * 根据orgId查询库存数量
	 * @param orgId
	 * @return
	 */
	List<DataKcglKcswDefault> queryKcData(Integer orgId,Integer houseId,Integer warehouseId);

	/**
	 * 查询库存总量
	 * @param map
	 * @return
	 */
	String countByBl(Map<String, Object> map);


	List<DataKcglKcswDefault> getDateByChHwh(Map<String, Object> modelMap);
	
	Map<String, Object> findNumManager(Map<String, Object> map);

	/**
	 * 修改库存实物表中对应仓房货位的粮食性质
	 * 
	 * @param record 要修改的值
	 * @param example 修改条件
	 */
	void updateKcswLsxz(DataKcglKcswDefault record, DataKcglKcswDefaultExample example);

	/**
	 * 查询库存实物表数据和入仓时间
	 * @param map
	 * @return
	 */
    List<DataKcglKcswDefault> findListOrRcsj(Map<String, Object> map);

    /**
     * 分别查询油罐、粮仓、粮和油所有的储量
     * 
     * @param orgId
     * @return
     */
	Map<String, Object> countByBlType(Integer orgId);

	/**
	 * 查询库存数量列表
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @param kcswStr
	 * @param order
	 * @return
	 * @throws Exception
	 */
	PageInfo<DataKcglKcswDefault> queryYYSSL(Integer pageNum, Integer pageSize, String kcswStr, String order) throws Exception;

	/**
	 * 导出库存数量数据为Excel
	 * 
	 * @param kcswStr
	 * @param order
	 * @return
	 * @throws Exception
	 */
	List<DataKcglKcswDefault> importList(HttpServletRequest request, HttpServletResponse response, String kcswStr, String order) throws Exception;

	/**
	 * 获取不是空仓的仓房库存数据
	 * @param orgId
	 * @param ch
	 * @return
	 */
    Map<String, Object> queryFkcfData(String orgId, Integer ch) throws Exception;
}
